@@ -4,6 +4,12 @@
 /* this file may be redistributed under the terms of the */
 /* GNU Public License (GPL), see www.gnu.org */
 
+
+
+#define _LARGEFILE64_SOURCE
+#define _FILE_OFFSET_BITS 64
+
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -218,18 +224,16 @@ unsigned long check_path(char *dev_name, char *save_name)
     unlink(buf);
   }
   
-  if (S_ISBLK(st_buf.st_mode))          /* real device, not image file */
+  if (stat(dev_name, &st_buf))        /* find device number of dev_name */
   {
-    if (stat(dev_name, &st_buf))        /* find device number of dev_name */
-    {
-      perror(dev_name);
-      return 0;
-    }
-    devnr = st_buf.st_rdev;
+    perror(dev_name);
+    return 0;
   }
+  if (S_ISBLK(st_buf.st_mode))          /* real device, not image file */
+   devnr = st_buf.st_rdev;
   else devnr = 1;                       /* we return devnr, and 0 is error */
 
-  if (devnr > 1)                        /* real file */
+  if (devnr > 1)                        /* real device */
   {
     f = fopen("/etc/mtab", "r");        /* dev_name mounted? */
     if (f)
